function [ Phat, Shat ] = beamformer( H, B, ESES )
%
% inputs:
% H(Nc,Nv): lead field   
% B(Nc,Nt): sensor data   
%
% outputs:
% Phat(Nv): power outputs
%
% if ESES==[] (empty), eigenspace projection NOT implemented.
% if ESES~=[] (non-empty), eigenspace projection implemented.
%
  [~,Nt]=size(B);
    Nv=size(H,2);
%
% computing covariance matrix
%    
  Rzz=B*B'/Nt;
  iRzz=inv(Rzz);
%
%  matrix preallocation ------------------------
%
 Phat=zeros(Nv,1);
 Shat=zeros(Nv,Nt);
%          
for iv=1:Nv
     hv=H(:,iv); 
     xi=1/(hv'*iRzz*hv);
     ww=xi*iRzz*hv; 
     if isempty(ESES)==0
         eww=ESES*ww;
         Shat(iv,:)=eww'*B;
     else
         Shat(iv,:)=ww'*B;
     end
     Phat(iv)=xi;
end
 
end

