function [ Shat, Phat ] = min_norm( H, B, gamma )
%
% min-norm(delay-and-sum beamforming)ASY
%------------------------------------
%  programmed by K. Sekihara
%  All right reserved by K. Sekihara
%  {R[h̎gpɍۂĂREADME.pdfɂgpmFĂ
%---------------------------------------------------------
% inputs:
% H(Nc,Nv): lead field   
% B(Nc,Nt): sensor data  
% gamma: relative regularization parameter
%
% outputs:
% Phat(Nv): power outputs
% Shat(Nv,Nt): voxel time course estimate
%
  [~,Nt]=size(B);
    Nv=size(H,2);
%
% computing covariance matrix
%    
  Rzz=B*B'/Nt;
%
% computing Gram matrix
%
  G0=H*H';
  G=G0 +gamma* max(eig(G0))*eye(size(G0));
  iG=inv(G);
  Azz=iG*Rzz*iG;
%
% minimum-norm XL
  Phat=zeros(Nv,1);
  Shat=zeros(Nv,Nt);
%          
for iv=1:Nv
     hv=H(:,iv); 
     Phat(iv)=hv'*Azz*hv;
     ww=iG*hv;
     Shat(iv,:)=ww'*B;
end
 
end

